@@ -1,6 +1,6 @@
 """This package contains all methods for serialization and deserialization of KNX/IP packets."""
 # flake8: noqa
-from .body import KNXIPBody
+from .body import KNXIPBody, KNXIPBodyResponse
 from .cemi_frame import CEMIFrame
 from .connect_request import ConnectRequest
 from .connect_response import ConnectResponse
@@ -14,7 +14,6 @@ from .header import KNXIPHeader
 from .hpai import HPAI
 from .knxip import KNXIPFrame
 from .knxip_enum import (
-    APCICommand,
     CEMIFlags,
     CEMIMessageCode,
     ConnectRequestType,
@@ -28,3 +27,35 @@ from .search_request import SearchRequest
 from .search_response import SearchResponse
 from .tunnelling_ack import TunnellingAck
 from .tunnelling_request import TunnellingRequest
+
+__all__ = [
+    "KNXIPBody",
+    "KNXIPBodyResponse",
+    "CEMIFrame",
+    "ConnectRequest",
+    "ConnectResponse",
+    "ConnectionStateRequest",
+    "ConnectionStateResponse",
+    "DIB",
+    "DIBDeviceInformation",
+    "DIBGeneric",
+    "DIBSuppSVCFamilies",
+    "DisconnectRequest",
+    "DisconnectResponse",
+    "ErrorCode",
+    "KNXIPHeader",
+    "HPAI",
+    "KNXIPFrame",
+    "CEMIFlags",
+    "CEMIMessageCode",
+    "ConnectRequestType",
+    "DIBServiceFamily",
+    "DIBTypeCode",
+    "KNXIPServiceType",
+    "KNXMedium",
+    "RoutingIndication",
+    "SearchRequest",
+    "SearchResponse",
+    "TunnellingAck",
+    "TunnellingRequest",
+]
